@@ -7,8 +7,8 @@ from typing import Tuple, List
 import numpy as np
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
-from pydwf.core.auxiliary.enum_types import (DwfTriggerLength, DwfTriggerSource, DwfTriggerType, DwfTriggerSlope,
-                                             DwfAnalogInFilter, DwfAcquisitionMode, DwfState)
+from pydwf.core.auxiliary.enum_types import (DwfTriggerLengthCondition, DwfTriggerSource, DwfTriggerType,
+                                             DwfTriggerSlope, DwfAnalogInFilter, DwfAcquisitionMode, DwfState)
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.exceptions import PyDwfError
 from pydwf.core.api.sub_api import DwfDevice_SubAPI
@@ -1725,11 +1725,11 @@ class AnalogIn(DwfDevice_SubAPI):
         trigger_length = c_trigger_length.value
         return trigger_length
 
-    def triggerLengthConditionInfo(self) -> List[DwfTriggerLength]:
+    def triggerLengthConditionInfo(self) -> List[DwfTriggerLengthCondition]:
         """Get |AnalogIn| trigger detector length condition info.
 
         Returns:
-            List[DwfTriggerLength]: The valid trigger length condition values that can be selected.
+            List[DwfTriggerLengthCondition]: The valid trigger length condition values that can be selected.
 
         Raises:
             DwfLibraryError: There was an error while getting the trigger length condition info.
@@ -1739,14 +1739,14 @@ class AnalogIn(DwfDevice_SubAPI):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
         triglen_bitset = c_triglen_bitset.value
-        triglen_list = [triglen for triglen in DwfTriggerLength if triglen_bitset & (1 << triglen.value)]
+        triglen_list = [triglen for triglen in DwfTriggerLengthCondition if triglen_bitset & (1 << triglen.value)]
         return triglen_list
 
-    def triggerLengthConditionSet(self, trigger_length_condition: DwfTriggerLength) -> None:
+    def triggerLengthConditionSet(self, trigger_length_condition: DwfTriggerLengthCondition) -> None:
         """Set |AnalogIn| trigger detector length condition.
 
         Parameters:
-            trigger_length_condition (DwfTriggerLength): The trigger length condition to be configured.
+            trigger_length_condition (DwfTriggerLengthCondition): The trigger length condition to be configured.
 
         Raises:
             DwfLibraryError: There was an error while setting the trigger length condition.
@@ -1757,11 +1757,11 @@ class AnalogIn(DwfDevice_SubAPI):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerLengthConditionGet(self) -> DwfTriggerLength:
+    def triggerLengthConditionGet(self) -> DwfTriggerLengthCondition:
         """Get |AnalogIn| trigger detector length condition.
 
         Returns:
-            DwfTriggerLength: The currently configured trigger length condition.
+            DwfTriggerLengthCondition: The currently configured trigger length condition.
 
         Raises:
             DwfLibraryError: There was an error while getting the trigger length condition.
@@ -1772,7 +1772,7 @@ class AnalogIn(DwfDevice_SubAPI):
             c_trigger_length_condition)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_length_condition = DwfTriggerLength(c_trigger_length_condition.value)
+        trigger_length_condition = DwfTriggerLengthCondition(c_trigger_length_condition.value)
         return trigger_length_condition
 
     def samplingSourceSet(self, sampling_source: DwfTriggerSource) -> None:
