@@ -13,7 +13,7 @@ from pydwf.core.api.sub_api import DwfDevice_SubAPI
 class AnalogIO(DwfDevice_SubAPI):
     """The |AnalogIO| class provides access to the analog I/O functionality of a |DwfDevice:link|.
 
-    The |AnalogIO| functions are used to control the power supplies, reference voltage supplies, voltmeters, ammeters,
+    The |AnalogIO| methods are used to control the power supplies, reference voltage supplies, voltmeters, ammeters,
     thermometers, and any other sensors on the device. These are organized into channels which contain a number of
     nodes. For instance, a power supply channel might have three nodes: an enable setting, a voltage level
     setting/reading, and current limitation setting/reading.
@@ -26,7 +26,7 @@ class AnalogIO(DwfDevice_SubAPI):
     """
 
     def reset(self) -> None:
-        """Reset and configure all AnalogIO instrument parameters to default values.
+        """Reset and configure all |AnalogIO| parameters to default values.
 
         If auto-configure is enabled, the changes take immediate effect.
 
@@ -38,7 +38,7 @@ class AnalogIO(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def configure(self) -> None:
-        """Configure the AnalogIO instrument.
+        """Configure the |AnalogIO| functionality.
 
         Raises:
             DwfLibraryError: There was an error while executing the configure operation.
@@ -64,18 +64,18 @@ class AnalogIO(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def enableInfo(self) -> Tuple[bool, bool]:
-        """Verify if Master Enable Setting and/or Master Enable Status are supported for the AnalogIO instrument.
+        """Verify if Master Enable Setting and/or Master Enable Status are supported.
 
-        The Master Enable setting is essentially a software switch that "enables" or "turns on" the AnalogIO channels.
+        The Master Enable setting is essentially a software switch that "enables" or "turns on" the |AnalogIO| channels.
 
         If supported, the current status of this Master Enable switch (Enabled/Disabled) can be queried by calling the
         :py:meth:`enableStatus` method.
 
-        The Master Enable *status* may be different from the Master Enable *setting* if e.g. an overcurrent protection
+        The Master Enable *status* may be different from the Master Enable *setting* if e.g. an over-current protection
         circuit has been triggered.
 
         Returns: Tuple[bool, bool]:
-            The elements indicate whether Master Enable 8set* and *status* are supported by the |AnalogIO| device.
+            The elements indicate whether Master Enable *set* and *status* are supported by the |AnalogIO| device.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -123,7 +123,7 @@ class AnalogIO(DwfDevice_SubAPI):
     def enableStatus(self) -> bool:
         """Return the actual master enable status (if the device supports it).
 
-        The Master Enable *status* may be different from the Master Enable *setting* if e.g. an overcurrent protection
+        The Master Enable *status* may be different from the Master Enable *setting* if e.g. an over-current protection
         circuit has been triggered.
 
         Returns:
@@ -252,7 +252,7 @@ class AnalogIO(DwfDevice_SubAPI):
     def channelNodeSetInfo(self, channel_index: int, node_index: int) -> Tuple[float, float, int]:
         """Return node value limits.
 
-        Since a Node can represent many things (Power supply, Temperature sensor, etc.),
+        Since a node can represent many things (power supply, temperature sensor, etc.),
         the *minimum*, *maximum*, and *steps* parameters also represent different types of values.
 
         :py:meth:`channelNodeInfo` returns the type of values to expect and :py:meth:`channelNodeName`
@@ -290,8 +290,9 @@ class AnalogIO(DwfDevice_SubAPI):
         """Set the node value for the specified node on the specified channel.
 
         Parameters:
-            channel_index (int): The channel from which we want to get the currently configured value.
-            node_index (int): The node from which we want to get the currently configured value.
+            channel_index (int): The channel for which we want to set the value.
+            node_index (int): The node for which we want to set the value.
+            node_value (float): The value we want to set the node to.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -326,14 +327,14 @@ class AnalogIO(DwfDevice_SubAPI):
         return node_value
 
     def channelNodeStatusInfo(self, channel_index: int, node_index: int) -> Tuple[float, float, int]:
-        """Return the range of reading values available for the specified node on the specified channel.
+        """Return the range of status values available for the specified node on the specified channel.
 
         Parameters:
             channel_index (int): The channel from which we want to get status information.
             node_index (int): The node from which we want to get status information.
 
         Returns:
-            Tuple[float, float, int]: the minimum and maximum values for the specified node,
+            Tuple[float, float, int]: the minimum and maximum status values for the specified node,
             and the number of resolution steps.
 
         Raises:
@@ -357,7 +358,7 @@ class AnalogIO(DwfDevice_SubAPI):
         return (min_value, max_value, num_steps)
 
     def channelNodeStatus(self, channel_index: int, node_index: int) -> float:
-        """Return the most recent value reading of the node.
+        """Return the most recent status value reading of the node.
 
         To fetch updated values for all |AnalogIO| nodes, use the :py:meth:`status` method.
 
